This CBDA function consolidates all the M workspaces generated in the Learning/Training step into a single workspace. It also ranks all the predictive models and selects the **top** ones to be sifted for top predictive features to be passed to the next step (i.e., **the Validation Step**).
CBDA_Consolidation(top, max_covs, M, misValperc, range_k, range_n, label,
workspace_directory = tempdir())Top predictions to select out of the M
Top features to display and include in the Validation Step where nested models are tested
Number of the BigData subsets on which perform Knockoff Filtering and SuperLearner feature mining
Percentage of missing values to introduce in BigData (used just for testing, to mimic real cases).
Features Sampling Range - FSR
Cases Sampling Range - CSR
This is the label appended to RData workspaces generated within the CBDA calls
Directory where the results and workspaces are saved
value