This CBDA function generates a stopping criteria for the *max_covs - min_covs* nested predictive models generated in the previous step. It also populates the CBDA object.
CBDA_Stopping_Criteria(label = "CBDA_package_test", Kcol_min = 5,
Kcol_max = 15, Nrow_min = 30, Nrow_max = 50, misValperc = 0,
M = 3000, workspace_directory = tempdir(), max_covs = 100,
min_covs = 5, lambda = 1.005)This is the label appended to RData workspaces generated within the CBDA calls
Lower bound for the percentage of features-columns sampling (used for the Feature Sampling Range - FSR)
Upper bound for the percentage of features-columns sampling (used for the Feature Sampling Range - FSR)
Lower bound for the percentage of cases-rows sampling (used for the Case Sampling Range - CSR)
Upper bound for the percentage of cases-rows sampling (used for the Case Sampling Range - CSR)
Percentage of missing values to introduce in BigData (used just for testing, to mimic real cases).
Number of the BigData subsets on which perform Knockoff Filtering and SuperLearner feature mining
Directory where the results and workspaces are saved
Top features to include in the Validation Step where nested models are tested
Minimum number of top features to include in the initial model for the Validation Step
Fisher test threshold for MSE (=1.005 by default)
value